+++
title = "Number all levels"
tags = ["export-option", "toc", "num"]
draft = false
+++

## <span class="section-num">1</span> Post sub-heading 1 {#post-sub-heading-1}


### <span class="section-num">1.1</span> Post sub-heading 1.1 {#post-sub-heading-1-dot-1}


#### <span class="section-num">1.1.1</span> Post sub-heading 1.1.1 {#post-sub-heading-1-dot-1-dot-1}


### <span class="section-num">1.2</span> Post sub-heading 1.2 {#post-sub-heading-1-dot-2}


### <span class="section-num">1.3</span> Post sub-heading 1.3 {#post-sub-heading-1-dot-3}


## <span class="section-num">2</span> Post sub-heading 2 {#post-sub-heading-2}


### <span class="section-num">2.1</span> Post sub-heading 2.1 {#post-sub-heading-2-dot-1}


### <span class="section-num">2.2</span> Post sub-heading 2.2 {#post-sub-heading-2-dot-2}


#### <span class="section-num">2.2.1</span> Post sub-heading 2.2.1 {#post-sub-heading-2-dot-2-dot-1}


#### Post sub-heading 2.2.2 {#post-sub-heading-2-dot-2-dot-2}

The `UNNUMBERED` property for this subtree is set to `t`. So this
heading will show up as unnumbered in both the post body and the TOC.


#### <span class="section-num">2.2.2</span> Post sub-heading 2.2.3 {#post-sub-heading-2-dot-2-dot-3}


## <span class="section-num">3</span> Post sub-heading 3 {#post-sub-heading-3}


### <span class="section-num">3.1</span> Post sub-heading 3.1 {#post-sub-heading-3-dot-1}
